============
Contributing
============

Contributions are welcome.  To ensure that your contributions are accepted
please follow these guidelines.

* Follow pep8 (Travis will fails builds that don't pass flake8)
* If you are adding docstrings, follow pep257
* If you are adding new functionality or fixing a bug, please add tests.
* If you are making a large change, consider filing an issue on github
  first to see if there are any objections to the proposed changes.

In general, new features or bug fixes **will not be merged unless they
have tests.**  This is not only to ensure the correctness of
the code, but to also encourage others to expirement without wondering
whether or not they are breaking existing code.
